# Woclema - Weblob, Originally Command Line Editable/Manageable
# Copyright (C) 2006-2007 Tommi Saviranta  <wnd@iki.fi>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA


package Woclema::Common;

use strict;
use warnings FATAL => 'all';
use diagnostics;

use Time::HiRes;

my $i_start_time;

BEGIN {
	$i_start_time = [&Time::HiRes::gettimeofday()];
};



my @links;


=item links_add
Add link to link list

0: url
1: label
=cut
sub links_add($$) {
	my ($url, $label) = @_;
	(defined($url) && defined($label)) || return;
	push(@links, $url, $label);
}


=item links_clear
Clear links list
=cut
sub links_clear() {
	@links = ();
}


=item print_links
Print links, cached or given.

@: links (or undef for internal list)
	(url, label) ...
=cut
sub print_links(@) {
	my @print_links;
	if ($#_ > -1) {
		@print_links = reverse(@_);
	} else {
		@print_links = reverse(@links);
	}

	($#print_links == -1) && return;

	print "<p>";

	my ($label, $url);
	$url = pop(@print_links);
	$label = pop(@print_links);
	print "\t<a href=\"$url\">\u$label</a>";

	while ($#print_links >= 0) {
		$url = pop(@print_links);
		$label = pop(@print_links);
		print ",\n\t<a href=\"$url\">$label</a>";
	}

	print "</p>\n";
}


=item max
Return maximum of two.

@: values
r: max
=cut
sub max(@) {
	my $max = shift;
	foreach (@_) {
		$max = $_ if ($_ > $max);
	}
	return $max;
}


=item min
Return minumum of two.

@: values
r: min
=cut
sub min(@) {
	my $min = shift;
	foreach (@_) {
		$min = $_ if ($_ < $min);
	}
	return $min;
}


=item process_time
Get process time for start of the script in microseconds

r: Time elapsed
=cut
sub process_time() {
	return &Time::HiRes::tv_interval($i_start_time);
}


=item compare_rank_asc
Compare two "ranked", i.e. "rank \t string" e.g. "123 foo".

0: a
1: b
r: value suitable for sort()
=cut
sub compare_rank_asc($$) {	# XXX
	my ($a, $b) = @_;
	my ($av) = $a =~ /(\d+)\s/;
	my ($bv) = $b =~ /(\d+)\s/;
	return $av <=> $bv;
}


=item compare_rank_desc
Compare two "ranked", i.e. "rank \t string" e.g. "123 foo".

0: a
1: b
r: value suitable for sort()
=cut
sub compare_rank_desc($$) {	# XXX
	my ($a, $b) = @_;
	my ($av) = $a =~ /(\d+)\s/;
	my ($bv) = $b =~ /(\d+)\s/;
	return $bv <=> $av;
}


=item make_unit
Make counter + unit.

0: value
1: singular
2: plural
r: string
=cut
sub make_unit($$$) {
	my ($unit, $singular, $plural) = @_;
	if (abs($unit) >= 2 || $unit == 0) {
		return sprintf("%d %s", $unit, $plural);
	} else {
		return sprintf("%d %s", $unit, $singular);
	}
}


return 1;
