# Woclema - Weblob, Originally Command Line Editable/Manageable
# Copyright (C) 2006-2007 Tommi Saviranta  <wnd@iki.fi>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA


package Woclema::HTML;

use strict;
use warnings FATAL => 'all';
use diagnostics;

use Woclema::Config;
use Woclema::Common;

my @content;
my @sidebar;

=item print
Print page.
=cut
sub print() {
	open(FILE, "< template") or die "Cannot read template file: $!";
	my $t;
	while (<FILE>) {
		$t .= $_;
	}
	close(FILE);

	my $x;
	
	$x = ($#content >= 0) ? join("\n", @content) : "";
	$t =~ s/__WOCLEMA_ENTRY__/$x/;

	$x = ($#sidebar >= 0) ? join("\n", @sidebar) : "";
	$t =~ s/__WOCLEMA_SIDEBAR__/$x/;

	$x = sprintf("%.3f", &Woclema::Common::process_time());
	$t =~ s/__WOCLEMA_TIME__/$x/;

	print "$t\n";
}


=item add_content
Write page content.

@: content (lines)
=cut
sub add_content(@) {
	push(@content, @_);
}


=item add_sidebar
Write content to sidebar.

@: content (lines)
=cut
sub add_sidebar(@) {
	push(@sidebar, @_);
}


=item bad_param
Act upon bad parameters

0: msg
=cut
sub bad_param($) {		# XXX
	my ($msg) = @_;
	print "<h1>LOL WTF n00b I pwn</h1>\n";
	(defined($msg)) && print "<p>$msg</p>\n";
	&print_footer();
	exit(0);
}


=item esc_param
Make parameters safe

@: options
r: parameter string
=cut
sub esc_param(@) {		# XXX
	my $url = "";
	my $first = 1;
	foreach (@_) {
		my $i = "$_";
		$i =~ s/#/%23/;
		$i =~ s/&/%26/;
		$i =~ s/\?/%3f/;
		if ($first == 0) {
			$url .= "&amp;";
		} else {
			$first = 0;
		}
		$url .= $i;
	}
	return $url;
}


=item truncate_url
Truncate URL nicely

0: url
1: len = 60
2: end = 10
r: url
=cut
sub truncate_url($$$) {		# XXX
	my ($url, $len, $end) = @_;
	$len = 60 if (! defined($len));
	$end = 10 if (! defined($end));

	my $rl = length($url);
	($rl <= $len) && return $url;

	# Can we do it nicely and cleanly?
	my ($domain, $path) = $url =~ /([a-z]+:\/\/.*?)\/(.*)/;
	if (! defined($domain)) {
		$domain = $url;
		$path = "";
	}
	if (length($domain) < $len) {
		my @t = split(/\//, $path);
		my $count = $#t + 1;
		while ($count > 1) {
			my $newurl = $domain . "/...";
			for (my $i = $#t + 1 - $count; $i < $#t + 1; $i++) {
				$newurl .= "/" . $t[$i];
			}
			if (length($newurl) <= $len) {
				return $newurl;
			}
			$count--;
		}
	}

	# Fallback...
	return (substr($url, 0, $len - $end - 3) . "..." .
			substr($url, $rl - $end));
}


=item htmlize
Make text proper HTML

0: string
r: html
=cut
sub htmlize($) {
	my ($t) = @_;
	$t =~ s/&/\&amp;/g;
	$t =~ s/</\&lt;/g;
	$t =~ s/>/\&gt;/g;
	return $t;
}


return 1;
