# Woclema - Weblob, Originally Command Line Editable/Manageable
# Copyright (C) 2007 Tommi Saviranta  <wnd@iki.fi>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA


package Woclema::Summary;

use strict;
use warnings FATAL => 'all';
use diagnostics;

use Woclema::DB;


=item all_time_entries
Get all-time summary for entries. Gives posts-per-month.

0: number of lines to return, default to 12
r: ( "count \t year \t month \t epoch " ) ..., ordered by year/month, descending
=cut
sub all_time_entries($) {
	my ($n) = @_;
	my ($query, $result);
	my @ret;

	$n = 12 unless defined($n);

	# AT TIME ZONE is really unnecessary...
	$query = &Woclema::DB::prepare(
			"SELECT count, " .
		"EXTRACT(YEAR FROM date AT TIME ZONE 'UTC') AS year, " .
		"EXTRACT(MONTH FROM date AT TIME ZONE 'UTC') AS month, " .
		"EXTRACT(EPOCH FROM date) AS epoch " .
			"FROM posts_per_month " .
			"LIMIT &da&");
	$query = &Woclema::DB::set($query, "a", $n);
	$result = &Woclema::DB::query($query);

	while (my ($count, $year, $month, $epoch) =
			&Woclema::DB::get_row($result)) {
		push(@ret, join("\t", $count, $year, $month, $epoch));
	}

	return @ret;
}


=item entries_per_category
Get list of entries, and number of entries for each category.

r: ( id \t count \t name ) ...
=cut
sub entries_per_category() {
	my ($query, $result);

	$query = &Woclema::DB::prepare(
			"SELECT cat.id, COUNT(cat.id) AS count, cat.name " .
			"FROM category AS cat, entry, entry_cat AS ecat " .
			"WHERE entry.id = ecat.entry " .
				"AND ecat.cat = cat.id " .
			"GROUP BY cat.id, cat.name");
	$result = &Woclema::DB::query($query);

	my @ret;
	while (my ($id, $count, $name) = &Woclema::DB::get_row($result)) {
		push(@ret, join("\t", $id, $count, $name));
	}

	return @ret;
}


return 1;
